
XEP 0115
========

.. module:: slixmpp.plugins.xep_0115

.. autoclass:: XEP_0115
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0115.stanza
    :members:
    :undoc-members:

